@@ -63,6 +63,7 @@
 #include "mlflat.h"
 #include "mlfflat.h"
 #include "mlgoto.h"
+#include "mlfgoto.h"
 
 #include "rubytable.h"
 #include "rubyftable.h"
@@ -345,8 +346,11 @@ CodeGenData *ocamlMakeCodeGen( const char *sourceFileName, const char *fsmName,
 	case GenGoto:
 		codeGen = new OCamlGotoCodeGen(out);
 		break;
+	case GenFGoto:
+		codeGen = new OCamlFGotoCodeGen(out);
+		break;
 	default:
-		cerr << "I only support the -T0 -T1 -F0 -F1 and -G0 output styles for OCaml.\n";
+		cerr << "I only support the -T0 -T1 -F0 -F1 -G0 and -G1 output styles for OCaml.\n";
 		exit(1);
 	}
 
@@ -1058,16 +1062,16 @@ void CodeGenData::write_option_error( InputLoc &loc, char *arg )
 	source_warning(loc) << "unrecognized write option \"" << arg << "\"" << endl;
 }
 
-void CodeGenData::writeStatement( InputLoc &loc, int nargs, char **args )
+/* returns true if the following section should generate line directives. */
+bool CodeGenData::writeStatement( InputLoc &loc, int nargs, char **args )
 {
-	/* FIXME: This should be moved to the virtual functions in the code
-	 * generators.
-	 *
-	 * Force a newline. */
-	out << '\n';
-	genLineDirective( out );
+	bool followLineDirective = false;
 
 	if ( strcmp( args[0], "data" ) == 0 ) {
+		out << '\n';
+		genLineDirective( out );
+		followLineDirective = true;
+
 		for ( int i = 1; i < nargs; i++ ) {
 			if ( strcmp( args[i], "noerror" ) == 0 )
 				noError = true;
@@ -1081,6 +1085,10 @@ void CodeGenData::writeStatement( InputLoc &loc, int nargs, char **args )
 		writeData();
 	}
 	else if ( strcmp( args[0], "init" ) == 0 ) {
+		out << '\n';
+		genLineDirective( out );
+		followLineDirective = true;
+
 		for ( int i = 1; i < nargs; i++ ) {
 			if ( strcmp( args[i], "nocs" ) == 0 )
 				noCS = true;
@@ -1090,6 +1098,10 @@ void CodeGenData::writeStatement( InputLoc &loc, int nargs, char **args )
 		writeInit();
 	}
 	else if ( strcmp( args[0], "exec" ) == 0 ) {
+		out << '\n';
+		genLineDirective( out );
+		followLineDirective = true;
+
 		for ( int i = 1; i < nargs; i++ ) {
 			if ( strcmp( args[i], "noend" ) == 0 )
 				noEnd = true;
@@ -1099,6 +1111,10 @@ void CodeGenData::writeStatement( InputLoc &loc, int nargs, char **args )
 		writeExec();
 	}
 	else if ( strcmp( args[0], "exports" ) == 0 ) {
+		out << '\n';
+		genLineDirective( out );
+		followLineDirective = true;
+
 		for ( int i = 1; i < nargs; i++ )
 			write_option_error( loc, args[i] );
 		writeExports();
@@ -1123,6 +1139,7 @@ void CodeGenData::writeStatement( InputLoc &loc, int nargs, char **args )
 		source_error(loc) << "unrecognized write command \"" << 
 				args[0] << "\"" << endl;
 	}
+	return followLineDirective;
 }
 
 ostream &CodeGenData::source_warning( const InputLoc &loc )
